@@ -13,7 +13,7 @@
 # under the License.
 from __future__ import annotations
 
-from typing import Union
+from typing import Union, NoReturn
 
 
 def raise_general_exception(
@@ -26,7 +26,7 @@ def raise_general_exception(
     raise GeneralError(msg) from previous
 
 
-def raise_bad_input_exception(msg: str):
+def raise_bad_input_exception(msg: str) -> NoReturn:
     raise BadInputError(msg)
 
 
