@@ -16,23 +16,33 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Any
 
 if TYPE_CHECKING:
-    from supertokens_python.recipe.emailpassword.interfaces import APIOptions, APIInterface
+    from supertokens_python.recipe.emailpassword.interfaces import (
+        APIOptions,
+        APIInterface,
+    )
 
 from supertokens_python.exceptions import raise_bad_input_exception
-from supertokens_python.utils import send_200_response
+from supertokens_python.utils import default_user_context, send_200_response
 
 from .utils import validate_form_fields_or_throw_error
 
 
-async def handle_generate_password_reset_token_api(api_implementation: APIInterface, api_options: APIOptions):
+async def handle_generate_password_reset_token_api(
+    api_implementation: APIInterface, api_options: APIOptions
+):
     if api_implementation.disable_generate_password_reset_token_post:
         return None
     body = await api_options.request.json()
     if body is None:
-        raise_bad_input_exception('Please provide a JSON body')
-    form_fields_raw: Any = body['formFields'] if 'formFields' in body else []
-    form_fields = await validate_form_fields_or_throw_error(api_options.config.reset_password_using_token_feature.form_fields_for_generate_token_form,
-                                                            form_fields_raw)
-    response = await api_implementation.generate_password_reset_token_post(form_fields, api_options, {})
+        raise_bad_input_exception("Please provide a JSON body")
+    form_fields_raw: Any = body["formFields"] if "formFields" in body else []
+    form_fields = await validate_form_fields_or_throw_error(
+        api_options.config.reset_password_using_token_feature.form_fields_for_generate_token_form,
+        form_fields_raw,
+    )
+    user_context = default_user_context(api_options.request)
 
+    response = await api_implementation.generate_password_reset_token_post(
+        form_fields, api_options, user_context
+    )
     return send_200_response(response.to_json(), api_options.response)
