@@ -14,7 +14,7 @@
 from __future__ import annotations
 
 from os import environ
-from typing import TYPE_CHECKING, Any, Dict, List, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, List, Union
 
 from supertokens_python.ingredients.emaildelivery import EmailDeliveryIngredient
 from supertokens_python.ingredients.emaildelivery.types import EmailDeliveryConfig
@@ -23,17 +23,18 @@ from supertokens_python.recipe.emailpassword.types import (
     EmailPasswordIngredients,
     EmailTemplateVars,
 )
-from supertokens_python.recipe.emailverification.types import (
-    EmailVerificationIngredients,
-    VerificationEmailTemplateVars,
-)
 from supertokens_python.recipe_module import APIHandled, RecipeModule
+from ..emailverification.interfaces import (
+    UnknownUserIdError,
+    GetEmailForUserIdOkResult,
+    EmailDoesNotExistError,
+)
 
-from ...exceptions import SuperTokensError
 from .api.implementation import APIImplementation
 from .exceptions import FieldError, SuperTokensEmailPasswordError
 from .interfaces import APIOptions
 from .recipe_implementation import RecipeImplementation
+from ...post_init_callbacks import PostSTInitCallbacks
 
 if TYPE_CHECKING:
     from supertokens_python.framework.request import BaseRequest
@@ -59,7 +60,6 @@ from .constants import (
     USER_PASSWORD_RESET_TOKEN,
 )
 from .utils import (
-    InputEmailVerificationConfig,
     InputOverrideConfig,
     InputResetPasswordUsingTokenFeature,
     InputSignUpFeature,
@@ -81,18 +81,14 @@ class EmailPasswordRecipe(RecipeModule):
         reset_password_using_token_feature: Union[
             InputResetPasswordUsingTokenFeature, None
         ] = None,
-        email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
         override: Union[InputOverrideConfig, None] = None,
-        email_verification_recipe: Union[EmailVerificationRecipe, None] = None,
         email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
     ):
         super().__init__(recipe_id, app_info)
         self.config = validate_and_normalise_user_input(
-            self,
             app_info,
             sign_up_feature,
             reset_password_using_token_feature,
-            email_verification_feature,
             override,
             email_delivery,
         )
@@ -111,24 +107,6 @@ class EmailPasswordRecipe(RecipeModule):
         else:
             self.email_delivery = email_delivery_ingredient
 
-        if email_verification_recipe is not None:
-            self.email_verification_recipe = email_verification_recipe
-        else:
-            ev_email_delivery_ingredient = cast(
-                EmailDeliveryIngredient[VerificationEmailTemplateVars],
-                self.email_delivery,
-            )
-
-            email_verification_ingredients = EmailVerificationIngredients(
-                email_delivery=ev_email_delivery_ingredient
-            )
-            self.email_verification_recipe = EmailVerificationRecipe(
-                recipe_id,
-                app_info,
-                self.config.email_verification_feature,
-                ingredients=email_verification_ingredients,
-            )
-
         api_implementation = APIImplementation()
         self.api_implementation = (
             api_implementation
@@ -136,12 +114,16 @@ class EmailPasswordRecipe(RecipeModule):
             else self.config.override.apis(api_implementation)
         )
 
+        def callback():
+            ev_recipe = EmailVerificationRecipe.get_instance_optional()
+            if ev_recipe:
+                ev_recipe.add_get_email_for_user_id_func(self.get_email_for_user_id)
+
+        PostSTInitCallbacks.add_post_init_callback(callback)
+
     def is_error_from_this_recipe_based_on_instance(self, err: Exception) -> bool:
         return isinstance(err, SuperTokensError) and (
             isinstance(err, SuperTokensEmailPasswordError)
-            or self.email_verification_recipe.is_error_from_this_recipe_based_on_instance(
-                err
-            )
         )
 
     def get_apis_handled(self) -> List[APIHandled]:
@@ -176,7 +158,7 @@ class EmailPasswordRecipe(RecipeModule):
                 SIGNUP_EMAIL_EXISTS,
                 self.api_implementation.disable_email_exists_get,
             ),
-        ] + self.email_verification_recipe.get_apis_handled()
+        ]
 
     async def handle_api_request(
         self,
@@ -192,7 +174,7 @@ class EmailPasswordRecipe(RecipeModule):
             self.recipe_id,
             self.config,
             self.recipe_implementation,
-            self.email_verification_recipe.recipe_implementation,
+            self.get_app_info(),
             self.email_delivery,
         )
         if request_id == SIGNUP:
@@ -207,9 +189,8 @@ class EmailPasswordRecipe(RecipeModule):
             )
         if request_id == USER_PASSWORD_RESET:
             return await handle_password_reset_api(self.api_implementation, api_options)
-        return await self.email_verification_recipe.handle_api_request(
-            request_id, request, path, method, response
-        )
+
+        return None
 
     async def handle_error(
         self, request: BaseRequest, err: SuperTokensError, response: BaseResponse
@@ -220,10 +201,10 @@ class EmailPasswordRecipe(RecipeModule):
                     {"status": "FIELD_ERROR", "formFields": err.get_json_form_fields()}
                 )
                 return response
-        return await self.email_verification_recipe.handle_error(request, err, response)
+        raise err
 
     def get_all_cors_headers(self) -> List[str]:
-        return self.email_verification_recipe.get_all_cors_headers()
+        return []
 
     @staticmethod
     def init(
@@ -231,7 +212,6 @@ class EmailPasswordRecipe(RecipeModule):
         reset_password_using_token_feature: Union[
             InputResetPasswordUsingTokenFeature, None
         ] = None,
-        email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
         override: Union[InputOverrideConfig, None] = None,
         email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
     ):
@@ -244,7 +224,6 @@ class EmailPasswordRecipe(RecipeModule):
                     ingredients,
                     sign_up_feature,
                     reset_password_using_token_feature,
-                    email_verification_feature,
                     override,
                     email_delivery=email_delivery,
                 )
@@ -276,10 +255,11 @@ class EmailPasswordRecipe(RecipeModule):
 
     async def get_email_for_user_id(
         self, user_id: str, user_context: Dict[str, Any]
-    ) -> str:
+    ) -> Union[UnknownUserIdError, GetEmailForUserIdOkResult, EmailDoesNotExistError]:
         user_info = await self.recipe_implementation.get_user_by_id(
             user_id, user_context
         )
-        if user_info is None:
-            raise Exception("Unknown User ID provided")
-        return user_info.email
+        if user_info is not None:
+            return GetEmailForUserIdOkResult(user_info.email)
+
+        return UnknownUserIdError()
