@@ -13,9 +13,10 @@
 # under the License.
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Dict, Union
+from typing import TYPE_CHECKING, Any, Dict, Union, Optional
 
 from jwt import decode
+
 from supertokens_python.utils import get_timestamp_ms
 
 from .constants import ACCESS_TOKEN_PAYLOAD_JWT_PROPERTY_NAME_KEY
@@ -27,6 +28,7 @@ if TYPE_CHECKING:
     from supertokens_python.recipe.session.interfaces import (
         RecipeInterface,
         SessionContainer,
+        SessionInformationResult,
     )
     from supertokens_python.framework.types import BaseRequest
 
@@ -90,7 +92,10 @@ def get_recipe_implementation_with_jwt(
         user_context: Dict[str, Any],
     ) -> Union[SessionContainer, None]:
         session_container = await og_get_session(
-            request, anti_csrf_check, session_required, user_context
+            request,
+            anti_csrf_check,
+            session_required,
+            user_context,
         )
         if session_container is None:
             return None
@@ -118,27 +123,25 @@ def get_recipe_implementation_with_jwt(
             user_context=user_context,
         )
 
-        await new_session.update_access_token_payload(access_token_payload)
+        await new_session.update_access_token_payload(
+            access_token_payload, user_context
+        )
         return get_session_with_jwt(new_session, openid_recipe_implementation)
 
     og_update_access_token_payload = original_implementation.update_access_token_payload
 
-    async def update_access_token_payload(
-        session_handle: str,
+    async def jwt_aware_update_access_token_payload(
+        session_information: SessionInformationResult,
         new_access_token_payload: Dict[str, Any],
         user_context: Dict[str, Any],
     ) -> bool:
-        session_information = await original_implementation.get_session_information(
-            session_handle, user_context
-        )
-        if session_information is None:
-            return False
-
         access_token_payload = session_information.access_token_payload
 
         if ACCESS_TOKEN_PAYLOAD_JWT_PROPERTY_NAME_KEY not in access_token_payload:
             return await og_update_access_token_payload(
-                session_handle, new_access_token_payload, user_context
+                session_information.session_handle,
+                new_access_token_payload,
+                user_context,
             )
 
         existing_jwt_property_name = access_token_payload[
@@ -177,11 +180,55 @@ def get_recipe_implementation_with_jwt(
         )
 
         return await og_update_access_token_payload(
-            session_handle, new_access_token_payload, user_context
+            session_information.session_handle, new_access_token_payload, user_context
+        )
+
+    async def update_access_token_payload(
+        session_handle: str,
+        new_access_token_payload: Optional[Dict[str, Any]],
+        user_context: Dict[str, Any],
+    ) -> bool:
+        if new_access_token_payload is None:
+            new_access_token_payload = {}
+
+        session_information = await original_implementation.get_session_information(
+            session_handle, user_context
+        )
+        if session_information is None:
+            return False
+
+        return await jwt_aware_update_access_token_payload(
+            session_information, new_access_token_payload, user_context
+        )
+
+    async def merge_into_access_token_payload(
+        session_handle: str,
+        access_token_payload_update: Dict[str, Any],
+        user_context: Dict[str, Any],
+    ) -> bool:
+        session_information = await original_implementation.get_session_information(
+            session_handle, user_context
+        )
+        if session_information is None:
+            return False
+
+        new_access_token_payload = {
+            **session_information.access_token_payload,
+            **access_token_payload_update,
+        }
+        for k in access_token_payload_update.keys():
+            if new_access_token_payload[k] is None:
+                del new_access_token_payload[k]
+
+        return await jwt_aware_update_access_token_payload(
+            session_information, new_access_token_payload, user_context
         )
 
     original_implementation.create_new_session = create_new_session
     original_implementation.get_session = get_session
     original_implementation.refresh_session = refresh_session
     original_implementation.update_access_token_payload = update_access_token_payload
+    original_implementation.merge_into_access_token_payload = (
+        merge_into_access_token_payload
+    )
     return original_implementation
