@@ -14,21 +14,14 @@
 from __future__ import annotations
 
 from os import environ
-from typing import TYPE_CHECKING, Any, Dict, List, Union, cast
+from typing import TYPE_CHECKING, List, Union
 
 from supertokens_python.framework.response import BaseResponse
 from supertokens_python.ingredients.emaildelivery.types import EmailDeliveryConfig
 from supertokens_python.normalised_url_path import NormalisedURLPath
 from supertokens_python.querier import Querier
 from supertokens_python.recipe.emailpassword.types import EmailPasswordIngredients
-from supertokens_python.recipe.emailverification.types import (
-    EmailVerificationIngredients,
-    VerificationEmailTemplateVars,
-)
 from supertokens_python.recipe.thirdparty.provider import Provider
-from supertokens_python.recipe.thirdparty.types import (
-    EmailTemplateVars as ThirdPartyEmailTemplateVars,
-)
 from supertokens_python.recipe.thirdparty.types import ThirdPartyIngredients
 from supertokens_python.recipe.thirdpartyemailpassword.types import (
     EmailTemplateVars,
@@ -54,7 +47,6 @@ from .recipeimplementation.implementation import RecipeImplementation
 from .recipeimplementation.third_party_recipe_implementation import (
     RecipeImplementation as ThirdPartyRecipeImplementation,
 )
-from .utils import InputEmailVerificationConfig
 
 if TYPE_CHECKING:
     from supertokens_python.framework.request import BaseRequest
@@ -66,7 +58,6 @@ from supertokens_python.recipe.emailpassword import EmailPasswordRecipe
 from supertokens_python.recipe.emailpassword.utils import (
     InputOverrideConfig as EPOverrideConfig,
 )
-from supertokens_python.recipe.emailverification import EmailVerificationRecipe
 from supertokens_python.recipe.thirdparty import ThirdPartyRecipe
 from supertokens_python.recipe.thirdparty.utils import (
     InputOverrideConfig as TPOverrideConfig,
@@ -96,10 +87,8 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
         reset_password_using_token_feature: Union[
             InputResetPasswordUsingTokenFeature, None
         ] = None,
-        email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
         override: Union[InputOverrideConfig, None] = None,
         providers: Union[List[Provider], None] = None,
-        email_verification_recipe: Union[EmailVerificationRecipe, None] = None,
         email_password_recipe: Union[EmailPasswordRecipe, None] = None,
         third_party_recipe: Union[ThirdPartyRecipe, None] = None,
         email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
@@ -109,7 +98,6 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
             self,
             sign_up_feature,
             reset_password_using_token_feature,
-            email_verification_feature,
             override,
             providers,
             email_delivery,
@@ -138,28 +126,11 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
         email_delivery_ingredient = ingredients.email_delivery
         if email_delivery_ingredient is None:
             self.email_delivery = EmailDeliveryIngredient(
-                self.config.get_email_delivery_config(
-                    self.recipe_implementation, ep_recipe_implementation
-                )
+                self.config.get_email_delivery_config(ep_recipe_implementation)
             )
         else:
             self.email_delivery = email_delivery_ingredient
 
-        if email_verification_recipe is not None:
-            self.email_verification_recipe = email_verification_recipe
-        else:
-            ev_email_delivery_ingredient = cast(
-                EmailDeliveryIngredient[VerificationEmailTemplateVars],
-                self.email_delivery,
-            )
-            ev_ingredients = EmailVerificationIngredients(ev_email_delivery_ingredient)
-            self.email_verification_recipe = EmailVerificationRecipe(
-                recipe_id,
-                app_info,
-                self.config.email_verification_feature,
-                ev_ingredients,
-            )
-
         if email_password_recipe is not None:
             self.email_password_recipe = email_password_recipe
         else:
@@ -178,11 +149,9 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
                 ep_ingredients,
                 self.config.sign_up_feature,
                 self.config.reset_password_using_token_feature,
-                None,
                 EPOverrideConfig(
                     func_override_email_password, apis_override_email_password
                 ),
-                self.email_verification_recipe,
             )
 
         if third_party_recipe is not None:
@@ -200,30 +169,21 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
                 return get_third_party_interface_impl(self.api_implementation)
 
             self.third_party_recipe: Union[ThirdPartyRecipe, None] = None
-            ingredient = cast(
-                EmailDeliveryIngredient[ThirdPartyEmailTemplateVars],
-                self.email_delivery,
-            )
-            tp_ingredients = ThirdPartyIngredients(ingredient)
+            tp_ingredients = ThirdPartyIngredients()
             if len(self.config.providers) != 0:
                 self.third_party_recipe = ThirdPartyRecipe(
                     recipe_id,
                     app_info,
                     SignInAndUpFeature(self.config.providers),
                     tp_ingredients,
-                    None,
                     TPOverrideConfig(
                         func_override_third_party, apis_override_third_party
                     ),
-                    self.email_verification_recipe,
                 )
 
     def is_error_from_this_recipe_based_on_instance(self, err: Exception) -> bool:
         return isinstance(err, SuperTokensError) and (
             isinstance(err, SupertokensThirdPartyEmailPasswordError)
-            or self.email_verification_recipe.is_error_from_this_recipe_based_on_instance(
-                err
-            )
             or self.email_password_recipe.is_error_from_this_recipe_based_on_instance(
                 err
             )
@@ -236,10 +196,7 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
         )
 
     def get_apis_handled(self) -> List[APIHandled]:
-        apis_handled = (
-            self.email_password_recipe.get_apis_handled()
-            + self.email_verification_recipe.get_apis_handled()
-        )
+        apis_handled = self.email_password_recipe.get_apis_handled()
         if self.third_party_recipe is not None:
             apis_handled = apis_handled + self.third_party_recipe.get_apis_handled()
         return apis_handled
@@ -269,9 +226,7 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
             return await self.third_party_recipe.handle_api_request(
                 request_id, request, path, method, response
             )
-        return await self.email_verification_recipe.handle_api_request(
-            request_id, request, path, method, response
-        )
+        return None
 
     async def handle_error(
         self, request: BaseRequest, err: SuperTokensError, response: BaseResponse
@@ -283,13 +238,10 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
             and self.third_party_recipe.is_error_from_this_recipe_based_on_instance(err)
         ):
             return await self.third_party_recipe.handle_error(request, err, response)
-        return await self.email_verification_recipe.handle_error(request, err, response)
+        raise err
 
     def get_all_cors_headers(self) -> List[str]:
-        cors_headers = (
-            self.email_password_recipe.get_all_cors_headers()
-            + self.email_verification_recipe.get_all_cors_headers()
-        )
+        cors_headers = self.email_password_recipe.get_all_cors_headers()
         if self.third_party_recipe is not None:
             cors_headers = cors_headers + self.third_party_recipe.get_all_cors_headers()
         return cors_headers
@@ -300,7 +252,6 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
         reset_password_using_token_feature: Union[
             InputResetPasswordUsingTokenFeature, None
         ] = None,
-        email_verification_feature: Union[InputEmailVerificationConfig, None] = None,
         override: Union[InputOverrideConfig, None] = None,
         providers: Union[List[Provider], None] = None,
         email_delivery: Union[EmailDeliveryConfig[EmailTemplateVars], None] = None,
@@ -315,7 +266,6 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
                         ingredients,
                         sign_up_feature,
                         reset_password_using_token_feature,
-                        email_verification_feature,
                         override,
                         providers,
                         email_delivery=email_delivery,
@@ -345,13 +295,3 @@ class ThirdPartyEmailPasswordRecipe(RecipeModule):
         ):
             raise Exception(None, "calling testing function in non testing env")
         ThirdPartyEmailPasswordRecipe.__instance = None
-
-    async def get_email_for_user_id(
-        self, user_id: str, user_context: Dict[str, Any]
-    ) -> str:
-        user_info = await self.recipe_implementation.get_user_by_id(
-            user_id, user_context
-        )
-        if user_info is None:
-            raise Exception("Unknown User ID provided")
-        return user_info.email
