@@ -95,9 +95,8 @@ class RecipeImplementation(RecipeInterface):
         third_party_id: str,
         third_party_user_id: str,
         email: str,
-        email_verified: bool,
         user_context: Dict[str, Any],
     ) -> SignInUpOkResult:
         return await self.recipe_implementation.thirdparty_sign_in_up(
-            third_party_id, third_party_user_id, email, email_verified, user_context
+            third_party_id, third_party_user_id, email, user_context
         )
