@@ -21,29 +21,26 @@ from django.test import RequestFactory, TestCase
 from supertokens_python import InputAppInfo, SupertokensConfig, init
 from supertokens_python.framework.django import middleware
 from supertokens_python.recipe import emailpassword, session
-from supertokens_python.recipe.emailpassword.interfaces import (APIInterface,
-                                                                APIOptions)
+from supertokens_python.recipe.emailpassword.interfaces import APIInterface, APIOptions
 from supertokens_python.recipe.session import SessionContainer
-from supertokens_python.recipe.session.asyncio import (create_new_session,
-                                                       get_session,
-                                                       refresh_session)
-from supertokens_python.recipe.session.framework.django.asyncio import \
-    verify_session
+from supertokens_python.recipe.session.asyncio import (
+    create_new_session,
+    get_session,
+    refresh_session,
+)
+from supertokens_python.recipe.session.framework.django.asyncio import verify_session
 from tests.utils import clean_st, reset, setup_st, start_st
 
 
 def get_cookies(response: HttpResponse) -> Dict[str, Any]:
     cookies: Dict[str, Any] = {}
     for key, morsel in response.cookies.items():
-        cookies[key] = {
-            'value': morsel.value,
-            'name': key
-        }
+        cookies[key] = {"value": morsel.value, "name": key}
         for k, v in morsel.items():
-            if (k in ('secure', 'httponly')) and v == '':
+            if (k in ("secure", "httponly")) and v == "":
                 cookies[key][k] = None
-            elif k == 'samesite':
-                if len(v) > 0 and v[-1] == ',':
+            elif k == "samesite":
+                if len(v) > 0 and v[-1] == ",":
                     v = v[:-1]
                 cookies[key][k] = v
             else:
@@ -52,13 +49,13 @@ def get_cookies(response: HttpResponse) -> Dict[str, Any]:
 
 
 async def create_new_session_view(request: HttpRequest):
-    await create_new_session(request, 'user_id')
-    return JsonResponse({'foo': 'bar'})
+    await create_new_session(request, "user_id")
+    return JsonResponse({"foo": "bar"})
 
 
 async def refresh_view(request: HttpRequest):
     await refresh_session(request)
-    return JsonResponse({'foo': 'bar'})
+    return JsonResponse({"foo": "bar"})
 
 
 async def custom_response_view(_: HttpRequest):
@@ -70,26 +67,25 @@ async def logout_view(request: HttpRequest):
     if session is None:
         raise Exception("Should never come here")
     await session.revoke_session()
-    return JsonResponse({'foo': 'bar'})
+    return JsonResponse({"foo": "bar"})
 
 
 async def handle_view(request: HttpRequest):
     session: Union[None, SessionContainer] = await get_session(request, True)
     if session is None:
         raise Exception("Should never come here")
-    return JsonResponse({'s': session.get_handle()})
+    return JsonResponse({"s": session.get_handle()})
 
 
 @verify_session(session_required=False)
 async def optional_session(request: HttpRequest):
     session: Union[None, SessionContainer] = request.supertokens  # type: ignore
     if session is None:
-        return JsonResponse({'s': "empty session"})
-    return JsonResponse({'s': session.get_handle()})
+        return JsonResponse({"s": "empty session"})
+    return JsonResponse({"s": session.get_handle()})
 
 
 class SupertokensTest(TestCase):
-
     def setUp(self):
         self.factory = RequestFactory()
         reset()
@@ -102,142 +98,166 @@ class SupertokensTest(TestCase):
 
     async def test_login_refresh(self):
         init(
-            supertokens_config=SupertokensConfig('http://localhost:3567'),
+            supertokens_config=SupertokensConfig("http://localhost:3567"),
             app_info=InputAppInfo(
                 app_name="SuperTokens Demo",
                 api_domain="http://api.supertokens.io",
                 website_domain="http://supertokens.io",
-                api_base_path="/auth"
+                api_base_path="/auth",
             ),
-            framework='django',
-            mode='asgi',
-            recipe_list=[session.init(
-                anti_csrf='VIA_TOKEN',
-                cookie_domain='supertokens.io'
-            )]
+            framework="django",
+            mode="asgi",
+            recipe_list=[
+                session.init(anti_csrf="VIA_TOKEN", cookie_domain="supertokens.io")
+            ],
         )
 
         start_st()
 
         my_middleware = middleware(create_new_session_view)
-        request = self.factory.get('/login', {'user_id': 'user_id'})
+        request = self.factory.get("/login", {"user_id": "user_id"})
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
         response = await temp
 
         my_middleware = middleware(refresh_view)
-        request = self.factory.get('/refresh', {'user_id': 'user_id'})
+        request = self.factory.get("/refresh", {"user_id": "user_id"})
         cookies = get_cookies(response)
 
-        assert len(cookies['sAccessToken']['value']) > 0
-        assert len(cookies['sIdRefreshToken']['value']) > 0
-        assert len(cookies['sRefreshToken']['value']) > 0
+        assert len(cookies["sAccessToken"]["value"]) > 0
+        assert len(cookies["sIdRefreshToken"]["value"]) > 0
+        assert len(cookies["sRefreshToken"]["value"]) > 0
 
-        request.COOKIES["sRefreshToken"] = cookies['sRefreshToken']['value']
-        request.COOKIES["sIdRefreshToken"] = cookies['sIdRefreshToken']['value']
-        request.META['HTTP_ANTI_CSRF'] = response.headers['anti-csrf']
+        request.COOKIES["sRefreshToken"] = cookies["sRefreshToken"]["value"]
+        request.COOKIES["sIdRefreshToken"] = cookies["sIdRefreshToken"]["value"]
+        request.META["HTTP_ANTI_CSRF"] = response.headers["anti-csrf"]
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
         response = await temp
         refreshed_cookies = get_cookies(response)
 
-        assert refreshed_cookies['sAccessToken']['value'] != cookies['sAccessToken']['value']
-        assert refreshed_cookies['sIdRefreshToken']['value'] != cookies['sIdRefreshToken']['value']
-        assert refreshed_cookies['sRefreshToken']['value'] != cookies['sRefreshToken']['value']
-        assert response.headers['anti-csrf'] is not None
-        assert refreshed_cookies['sAccessToken']['domain'] == cookies['sAccessToken']['domain']
-        assert refreshed_cookies['sIdRefreshToken']['domain'] == cookies['sIdRefreshToken']['domain']
-        assert refreshed_cookies['sRefreshToken']['domain'] == cookies['sRefreshToken']['domain']
-        assert refreshed_cookies['sAccessToken']['secure'] == cookies['sAccessToken']['secure']
-        assert refreshed_cookies['sIdRefreshToken']['secure'] == cookies['sIdRefreshToken']['secure']
-        assert refreshed_cookies['sRefreshToken']['secure'] == cookies['sRefreshToken']['secure']
+        assert (
+            refreshed_cookies["sAccessToken"]["value"]
+            != cookies["sAccessToken"]["value"]
+        )
+        assert (
+            refreshed_cookies["sIdRefreshToken"]["value"]
+            != cookies["sIdRefreshToken"]["value"]
+        )
+        assert (
+            refreshed_cookies["sRefreshToken"]["value"]
+            != cookies["sRefreshToken"]["value"]
+        )
+        assert response.headers["anti-csrf"] is not None
+        assert (
+            refreshed_cookies["sAccessToken"]["domain"]
+            == cookies["sAccessToken"]["domain"]
+        )
+        assert (
+            refreshed_cookies["sIdRefreshToken"]["domain"]
+            == cookies["sIdRefreshToken"]["domain"]
+        )
+        assert (
+            refreshed_cookies["sRefreshToken"]["domain"]
+            == cookies["sRefreshToken"]["domain"]
+        )
+        assert (
+            refreshed_cookies["sAccessToken"]["secure"]
+            == cookies["sAccessToken"]["secure"]
+        )
+        assert (
+            refreshed_cookies["sIdRefreshToken"]["secure"]
+            == cookies["sIdRefreshToken"]["secure"]
+        )
+        assert (
+            refreshed_cookies["sRefreshToken"]["secure"]
+            == cookies["sRefreshToken"]["secure"]
+        )
 
     async def test_login_logout(self):
         init(
-            supertokens_config=SupertokensConfig('http://localhost:3567'),
+            supertokens_config=SupertokensConfig("http://localhost:3567"),
             app_info=InputAppInfo(
                 app_name="SuperTokens Demo",
                 api_domain="http://api.supertokens.io",
                 website_domain="http://supertokens.io",
-                api_base_path="/auth"
+                api_base_path="/auth",
             ),
-            framework='django',
-            mode='asgi',
-            recipe_list=[session.init(
-                anti_csrf='VIA_TOKEN',
-                cookie_domain='supertokens.io'
-            )]
+            framework="django",
+            mode="asgi",
+            recipe_list=[
+                session.init(anti_csrf="VIA_TOKEN", cookie_domain="supertokens.io")
+            ],
         )
 
         start_st()
 
         my_middleware = middleware(create_new_session_view)
-        request = self.factory.get('/login', {'user_id': 'user_id'})
+        request = self.factory.get("/login", {"user_id": "user_id"})
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
         response = await temp
         cookies = get_cookies(response)
 
-        assert len(cookies['sAccessToken']['value']) > 0
-        assert len(cookies['sIdRefreshToken']['value']) > 0
-        assert len(cookies['sRefreshToken']['value']) > 0
+        assert len(cookies["sAccessToken"]["value"]) > 0
+        assert len(cookies["sIdRefreshToken"]["value"]) > 0
+        assert len(cookies["sRefreshToken"]["value"]) > 0
 
         my_middleware = middleware(logout_view)
-        request = self.factory.post('/logout', {'user_id': 'user_id'})
+        request = self.factory.post("/logout", {"user_id": "user_id"})
 
-        request.COOKIES["sAccessToken"] = cookies['sAccessToken']['value']
-        request.COOKIES["sIdRefreshToken"] = cookies['sIdRefreshToken']['value']
-        request.META['HTTP_ANTI_CSRF'] = response.headers['anti-csrf']
+        request.COOKIES["sAccessToken"] = cookies["sAccessToken"]["value"]
+        request.COOKIES["sIdRefreshToken"] = cookies["sIdRefreshToken"]["value"]
+        request.META["HTTP_ANTI_CSRF"] = response.headers["anti-csrf"]
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
         response = await temp
         logout_cookies = get_cookies(response)
-        assert response.headers.get('anti-csrf') is None  # type: ignore
-        assert logout_cookies['sAccessToken']['value'] == ''
-        assert logout_cookies['sRefreshToken']['value'] == ''
-        assert logout_cookies['sIdRefreshToken']['value'] == ''
+        assert response.headers.get("anti-csrf") is None  # type: ignore
+        assert logout_cookies["sAccessToken"]["value"] == ""
+        assert logout_cookies["sRefreshToken"]["value"] == ""
+        assert logout_cookies["sIdRefreshToken"]["value"] == ""
 
     async def test_login_handle(self):
         init(
-            supertokens_config=SupertokensConfig('http://localhost:3567'),
+            supertokens_config=SupertokensConfig("http://localhost:3567"),
             app_info=InputAppInfo(
                 app_name="SuperTokens Demo",
                 api_domain="http://api.supertokens.io",
                 website_domain="http://supertokens.io",
-                api_base_path="/auth"
+                api_base_path="/auth",
             ),
-            framework='django',
-            mode='asgi',
-            recipe_list=[session.init(
-                anti_csrf='VIA_TOKEN',
-                cookie_domain='supertokens.io'
-            )]
+            framework="django",
+            mode="asgi",
+            recipe_list=[
+                session.init(anti_csrf="VIA_TOKEN", cookie_domain="supertokens.io")
+            ],
         )
 
         start_st()
 
         my_middleware = middleware(create_new_session_view)
-        request = self.factory.get('/login', {'user_id': 'user_id'})
+        request = self.factory.get("/login", {"user_id": "user_id"})
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
         response = await temp
         cookies = get_cookies(response)
 
-        assert len(cookies['sAccessToken']['value']) > 0
-        assert len(cookies['sIdRefreshToken']['value']) > 0
-        assert len(cookies['sRefreshToken']['value']) > 0
+        assert len(cookies["sAccessToken"]["value"]) > 0
+        assert len(cookies["sIdRefreshToken"]["value"]) > 0
+        assert len(cookies["sRefreshToken"]["value"]) > 0
 
         my_middleware = middleware(handle_view)
-        request = self.factory.get('/handle', {'user_id': 'user_id'})
+        request = self.factory.get("/handle", {"user_id": "user_id"})
 
-        request.COOKIES["sAccessToken"] = cookies['sAccessToken']['value']
-        request.COOKIES["sIdRefreshToken"] = cookies['sIdRefreshToken']['value']
-        request.META['HTTP_ANTI_CSRF'] = response.headers['anti-csrf']
+        request.COOKIES["sAccessToken"] = cookies["sAccessToken"]["value"]
+        request.COOKIES["sIdRefreshToken"] = cookies["sIdRefreshToken"]["value"]
+        request.META["HTTP_ANTI_CSRF"] = response.headers["anti-csrf"]
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
@@ -249,37 +269,36 @@ class SupertokensTest(TestCase):
 
     async def test_login_refresh_error_handler(self):
         init(
-            supertokens_config=SupertokensConfig('http://localhost:3567'),
+            supertokens_config=SupertokensConfig("http://localhost:3567"),
             app_info=InputAppInfo(
                 app_name="SuperTokens Demo",
                 api_domain="http://api.supertokens.io",
                 website_domain="http://supertokens.io",
-                api_base_path="/auth"
+                api_base_path="/auth",
             ),
-            framework='django',
-            mode='asgi',
-            recipe_list=[session.init(
-                anti_csrf='VIA_TOKEN',
-                cookie_domain='supertokens.io'
-            )]
+            framework="django",
+            mode="asgi",
+            recipe_list=[
+                session.init(anti_csrf="VIA_TOKEN", cookie_domain="supertokens.io")
+            ],
         )
 
         start_st()
 
         my_middleware = middleware(create_new_session_view)
-        request = self.factory.get('/login', {'user_id': 'user_id'})
+        request = self.factory.get("/login", {"user_id": "user_id"})
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
         response = await temp
 
         my_middleware = middleware(refresh_view)
-        request = self.factory.get('/refresh', {'user_id': 'user_id'})
+        request = self.factory.get("/refresh", {"user_id": "user_id"})
         cookies = get_cookies(response)
 
-        assert len(cookies['sAccessToken']['value']) > 0
-        assert len(cookies['sIdRefreshToken']['value']) > 0
-        assert len(cookies['sRefreshToken']['value']) > 0
+        assert len(cookies["sAccessToken"]["value"]) > 0
+        assert len(cookies["sIdRefreshToken"]["value"]) > 0
+        assert len(cookies["sRefreshToken"]["value"]) > 0
 
         temp = my_middleware(request)
         if not isawaitable(temp):
@@ -293,8 +312,10 @@ class SupertokensTest(TestCase):
 
             original_func = original_implementation.email_exists_get
 
-            async def email_exists_get(email: str, api_options: APIOptions, user_context: Dict[str, Any]):
-                response_dict = {'custom': True}
+            async def email_exists_get(
+                email: str, api_options: APIOptions, user_context: Dict[str, Any]
+            ):
+                response_dict = {"custom": True}
                 api_options.response.set_status_code(203)
                 api_options.response.set_json_content(response_dict)
                 return await original_func(email, api_options, user_context)
@@ -303,27 +324,28 @@ class SupertokensTest(TestCase):
             return original_implementation
 
         init(
-            supertokens_config=SupertokensConfig('http://localhost:3567'),
+            supertokens_config=SupertokensConfig("http://localhost:3567"),
             app_info=InputAppInfo(
                 app_name="SuperTokens Demo",
                 api_domain="http://api.supertokens.io",
                 website_domain="http://supertokens.io",
-                api_base_path="/auth"
+                api_base_path="/auth",
             ),
-            framework='django',
-            mode='asgi',
-            recipe_list=[emailpassword.init(
-                override=emailpassword.InputOverrideConfig(
-                    apis=override_email_password_apis
+            framework="django",
+            mode="asgi",
+            recipe_list=[
+                emailpassword.init(
+                    override=emailpassword.InputOverrideConfig(
+                        apis=override_email_password_apis
+                    )
                 )
-            )]
+            ],
         )
 
         start_st()
 
         my_middleware = middleware(custom_response_view)
-        request = self.factory.get(
-            '/auth/signup/email/exists?email=test@example.com')
+        request = self.factory.get("/auth/signup/email/exists?email=test@example.com")
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
@@ -335,22 +357,22 @@ class SupertokensTest(TestCase):
 
     async def test_optional_session(self):
         init(
-            supertokens_config=SupertokensConfig('http://localhost:3567'),
+            supertokens_config=SupertokensConfig("http://localhost:3567"),
             app_info=InputAppInfo(
                 app_name="SuperTokens Demo",
                 api_domain="http://api.supertokens.io",
                 website_domain="http://supertokens.io",
-                api_base_path="/auth"
+                api_base_path="/auth",
             ),
-            framework='django',
-            mode='asgi',
-            recipe_list=[session.init()]
+            framework="django",
+            mode="asgi",
+            recipe_list=[session.init()],
         )
 
         start_st()
 
         my_middleware = middleware(optional_session)
-        request = self.factory.get('/handle-session-optional')
+        request = self.factory.get("/handle-session-optional")
         temp = my_middleware(request)
         if not isawaitable(temp):
             raise Exception("Should never come here")
